@@ -48,8 +48,11 @@ class NotificationAdmin(admin.ModelAdmin):
     readonly_fields = ('management',)
 
     fields = (
-        'name',
-        'message',
+        'name_en',
+        'name_is',
+        'message_en',
+        'message_is',
+        'active_from',
         'expires',
         'needs_approval',
         'snooze_time',
@@ -83,7 +86,7 @@ class NotificationAdmin(admin.ModelAdmin):
                 attr = ''.join(attr.split('\n'))
                 attr = ''.join(attr.split('\r'))
             params += ' --{}=\'{}\''.format(field.name, attr)
-        groups = ','.join(instance.groups.values_list('id', flat=True))
+        groups = ','.join(map(str, instance.groups.values_list('id', flat=True)))
         if groups:
             params += ' --groups={}'.format(groups)
 
